Installation — django-gwo v0.2 documentation

django-gwo v0.2 documentation

# Installation

- Table of Contents
- index
  modules
  next
  previous

- Main Page

- Installation
  - Dependencies
- Multivariate testing of dynamic pages
- Tutorial
- Getting Started
- Using the weboptimizer gdata Extension
- Management Commands
- Reference

Enter search terms or a module, class or function name.

# Installation

Installation is easy using `pip` or `easy_install`.

    pip install django-gwo

or

    easy_install django-gwo

## Dependencies

© Copyright 2010, The Washington Times. Created using Sphinx 1.0.6.

Installation